pub struct PluginResponse {
pub context: GenerateContext,
}Expand description
Stdout envelope. The subprocess returns the mutated context; the engine diffs the journal to confirm the subprocess didn’t forge sequence indices, then merges the new context back into the running pipeline state.
Fields
context: GenerateContextTrait Implementations
Sourceimpl Clone for PluginResponse
impl Clone for PluginResponse
Sourcefn clone(&self) -> PluginResponse
fn clone(&self) -> PluginResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginResponse
impl Debug for PluginResponse
Sourceimpl<'de> Deserialize<'de> for PluginResponse
impl<'de> Deserialize<'de> for PluginResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more